@@ -3,6 +3,7 @@ import numpy as np
 from abc import ABC, abstractmethod
 
 from genreml.model.model import input
+from genreml.model.cnn import dataset as ds
 
 
 class Model(ABC):
@@ -12,9 +13,9 @@ class Model(ABC):
         self.model = None
 
     @abstractmethod
-    def train(self):
+    def train(self, dataset: ds.Dataset, batch_size, epochs, optimizer):
         pass
 
     @abstractmethod
-    def predict(self, input_data: input.ModelInput) -> np.array:
+    def _predict(self, input_data: input.ModelInput) -> np.array:
         pass
