@@ -43,7 +43,7 @@ def process_youtube_video():
         youtube_url = request.form['text']
         # Only process results if valid youtube video link
         if "youtube" in youtube_url and youtube_url[:8] == "https://" and "v=" in youtube_url:
-            filepath = downloader.download_link(youtube_url="", directory_path=app.config['FILE_UPLOAD_LOCATION'])
+            filepath = downloader.download_link(youtube_url, directory_path=app.config['FILE_UPLOAD_LOCATION'])
             visual_feature_relative_paths = populate_visual_features(app.root_path, filepath)
             return render_template('results.html', visual_features=visual_feature_relative_paths)
     return render_template('index.html')
